# Partial example

This example shows how to run only parts of Optimal framework.

It is mostly for developers who wants to learn how the different parts work without all the code in the Broker.
Also, different ways of running the CherryPy server is shown.  